@@ -9,7 +9,9 @@ class Microsimulation(GeneralMicrosimulation):
     entities = entities
     default_dataset = CPS
 
-    def __init__(self, reform=(), dataset: type = CPS, year: int = None):
+    def __init__(
+        self, reform=(), dataset: type = CPS, year: int = None, **kwargs
+    ):
         if dataset == CPS and len(CPS.years) == 0:
             CPS.generate(2020)
 
